/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2012 University of Bonn. All rights reserved.
 * 
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * BoundaryConditionValidator.cpp
 *
 *  Created on: May 10, 2012
 *      Author: ankele
 */


// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

//#include "CodePatterns/MemDebug.hpp"

#include "BoundaryConditionValidator.hpp"

#include "Box.hpp"
#include "Box_BoundaryConditions.hpp"

BoundaryConditionValidator::BoundaryConditionValidator() :
  DiscreteValidator<std::string>(std::vector<std::string>())
{}

bool BoundaryConditionValidator::isValid(const std::string & _value) const
{
  BoundaryConditions::BCContainer bc;
  return (bc.ReConverterBiMap.find(_value) != bc.ReConverterBiMap.end());
}

const std::vector<std::string> &BoundaryConditionValidator::getValidValues() const
{
  BoundaryConditions::BCContainer bc;
  currentList.clear();
  for (BoundaryConditions::BCContainer::StringToEnumMap::iterator iter = bc.ReConverterBiMap.begin();
    iter != bc.ReConverterBiMap.end();
    iter ++)
    currentList.push_back(iter->first);
  return currentList;
}

bool BoundaryConditionValidator::operator==(const Validator<std::string> &_instance) const
{
  const BoundaryConditionValidator *inst =
      dynamic_cast<const BoundaryConditionValidator *>(&_instance);
  if (inst)
    return true;
  else
    return false;
}

Validator< std::string >* BoundaryConditionValidator::clone() const
{
  Validator< std::string > *inst =
      new BoundaryConditionValidator();
  return inst;
}




